#
# spec file for package python-Cheetah3
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define modname cheetah3
Name:           python-Cheetah3
Version:        3.4.0
Release:        bp160.2.2
Summary:        Template engine and code generation tool
License:        MIT
Group:          Development/Languages/Python
URL:            https://cheetahtemplate.org/
Source:         https://github.com/CheetahTemplate3/cheetah3/archive/refs/tags/%{version}.tar.gz#/%{modname}-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Recommends:     python-Markdown
Suggests:       python-Pygments
Conflicts:      python-Cheetah
Provides:       python-Cheetah = %{version}
Provides:       python-cheetah = %{version}
Obsoletes:      python-Cheetah < %{version}
# SECTION test requirements
BuildRequires:  %{python_module Markdown}
BuildRequires:  %{python_module Pygments}
# /SECTION
%python_subpackages

%description
Cheetah is an open source template engine and code generation tool.

It can be used standalone or combined with other tools and frameworks.
Web development is its principle use, but Cheetah is flexible and can
also be used to generate C++ game code, Java, SQL, form emails and even
Python code.

It is a fork of the original CheetahTemplate library.

%prep
%setup -q -n %{modname}-%{version}
%autopatch -p1
find . -name \*.py -print0 |xargs -0 -t -l sed -i -e '1{\@^#!%{_bindir}/env python@d}'

# Disable some tests which fail on Python 3.6
# * GetVar
# * GetVar_MacEOL
# * GetVar_Win32EOL
# TODO: The following disables ~100 tests, and should be optimised
sed -Ei 's/(test6)/_\1/' Cheetah/Tests/SyntaxAndOutput.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/cheetah
%python_clone -a %{buildroot}%{_bindir}/cheetah-analyze
%python_clone -a %{buildroot}%{_bindir}/cheetah-compile
%{python_expand rm -r %{buildroot}%{$python_sitearch}/Cheetah/Tests
%fdupes %{buildroot}%{$python_sitearch}
}

%post
%python_install_alternative cheetah cheetah-analyze cheetah-compile

%postun
%python_uninstall_alternative cheetah

%check
mkdir ~/bin
export PATH=~/bin:$PATH
%{python_expand export PYTHONPATH=$PWD
cp %{buildroot}/%{_bindir}/cheetah-%{$python_bin_suffix} ~/bin/cheetah
export PYTHONDONTWRITEBYTECODE=1
$python Cheetah/Tests/Test.py
}

%files %{python_files}
%license LICENSE
%doc ANNOUNCE.rst README.rst BUGS
%python_alternative %{_bindir}/cheetah
%python_alternative %{_bindir}/cheetah-analyze
%python_alternative %{_bindir}/cheetah-compile
%{python_sitearch}/Cheetah
%{python_sitearch}/[Cc][Tt]3-%{version}.dist-info

%changelog
* Mon Apr 14 2025 Steve Kowalik <steven.kowalik@suse.com>
- Support both lowercased and unnormalized metadata directory names.
* Tue Mar 25 2025 Steve Kowalik <steven.kowalik@suse.com>
- Lowercase metadata directory name.
* Tue Dec 10 2024 Markéta Machová <mmachova@suse.com>
- Update to 3.4.0
  * Fixed ImportHooks: it must raise ModuleNotFoundError instead of ImportError.
  * Use cache_from_source in ImportManager to find out .pyc/.pyo byte-code files.
  * Add compatibility with Python 3.13 (multiple fixes)
* Tue Aug 27 2024 Frantisek Simorda <frantisek.simorda@suse.com>
- update to 3.3.3.post1:
  * GHActions: Build and publish wheels on Linux/aarch64.
- version 3.3.3:
  * Protect import cgi in preparation to Python 3.13.
  * Run tests with Python 3.12.
  * GHActions: Ensure pip only if needed
- version 3.3.2:
  * Fixed printing to stdout in CheetahWrapper.
  * CI(GHActions): Install all Python and PyPy versions from conda-forge.
- version 3.3.1:
  * Fixed ImportHooks under PyPy3.
  * Run tests with PyPy3.
  * Use conda to install older Pythons
- version 3.3.0.post1:
  * Run tests with Python 3.11
  * Fix DeprecationWarning: unittest.findTestCases() is deprecated. Use unittest.TestLoader.loadTestsFromModule() instead
  * Publish wheels at Github Releases.
- version 3.3.0:
  * PyPI has wrongfully classified project Cheetah3 as “critical”. This puts a burden to use 2FA to manage the project at PyPI. To avoid the burden the project is renamed to CT3 at PyPI. There will be no updates for Cheetah3. Sorry for the inconvenience!
  * Use relative imports everywhere.
  * Run pure-python NameMapper tests in a separate process.
  * Fixed a bug in tests with pure-python NameMapper.
  * Add Python 3.10 to tox.ini.
  * Migrated to GitHub Actions.
- version 3.2.7b1:
  * Load from JSON file to searchlist (similar to loading from pickle).
  * Fix filetype for Python 2 in Template.
  * Build wheels for aarch64 at Travis; publish them at PyPI.
  * tox.ini: Limit VIRTUALENV_PIP version for Python 3.4.
* Tue Jan 11 2022 Steve Kowalik <steven.kowalik@suse.com>
- Update to 3.2.6.post1:
  * Skip test_import_bootlocale() on Python 3.10
* Thu Jan 21 2021 John Vandenberg <jayvdb@gmail.com>
- Add Suggests for python-Markdown and python-Pygments
- Use python_alternative to fix multi Python 3 builds
- Tidy spec
- Disable tests failing on Python 3.6
- update to 3.2.6
  * Fix use of uninitialized variable in _namemapper.c
* Wed Jul  8 2020 Ondřej Súkup <mimi.vx@gmail.com>
- update to 3.2.5
  * build fixes
* Tue Apr 21 2020 Matej Cepl <mcepl@suse.com>
- Cleanup of the SPEC file, remove warnings.
* Fri Feb 14 2020 trenn@suse.de
- python-Markdown is a BuildRequire for python-Cheetah3
  python2-Markdown package is not built anymore since last
  submitrequest:
  - disable python2 build: Markdown is python 3 only now
  Therefore python-Cheetah3 can also only build python3-Cheetah3
  due to: nothing provides python2-Markdown
  unresolvable build service errors otherwise
* Mon Oct  7 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.2.4:
  * Import from collections for Python 2, from collections.abc for Python 3.
  * Fixed infinite recursion in ImportManager on importing module _bootlocale inside open().
* Thu May 23 2019 pgajdos@suse.com
- version update to 3.2.3
  - Fixed infinite recursion in ``ImportManager`` on importing
    a builtin module.
  - The site https://cheetahtemplate.org/ is now served with HTTPS.
  - Updated docs regarding fixed tests.
* Tue May 21 2019 Tomáš Chvátal <tchvatal@suse.com>
- Do not provide Cheetah3 namespace on python2, if someone wants
  Cheetah3 binary they need the python3 variant anyway
* Fri May  3 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 3.2.2:
  * Replaced outdated and insecure mktemp with mkstemp.
  * Fixed bugs in TemplateCmdLineIface.py: read binary pickles from
    stdin and files.
  * Use cgi.escape() for Python 2, html.escape() for Python 3.
  * Created tests for TemplateCmdLineIface.
- Update test dependencies
* Thu Mar 21 2019 Tomáš Chvátal <tchvatal@suse.com>
- Enable py2 as it supports python2
- Update to 3.2.1:
  * Changed LoadTemplate.loadTemplate{Module,Class}: the loaded module’s __name__ set to just the file name.
  * Use imp for Python 2, importlib for Python 3.
  * Fix a bug in LoadTemplate.loadTemplate{Module,Class}: raise ImportError if the template was not found.
* Tue Mar  5 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.2.0:
  * Dropped support for Python 3.3.
  * Implement LoadTemplate.loadTemplate{Module,Class} to load templates from .py[co], .py or .tmpl.
  * CheetahDirOwner caches compiled template in the template directory.
  * CheetahDirOwner now silently ignores errors on compiled templates writing. To get tracebacks set CheetahDirOwner.debuglevel = 1.
  * CheetahDirOwner and DirOwner byte-compile compiled templates to .pyc/.pyo. Errors on writing are silently ignored.
  * Implement Compiler.__unicode__ under Python 2 and Compiler.__bytes__ under Python 3.
  * Fix a bug in Compiler.__str__: under Python 2 the method now always returns str; it encodes unicode to str using encoding from the compiled source. Under Python 3 the method decodes bytes to str.
- Execute tests
* Mon Dec 10 2018 Tomáš Chvátal <tchvatal@suse.com>
- Fix fdupes call
* Fri Apr  6 2018 mpluskal@suse.com
- Update to version 3.1.0:
  * Fix Cheetah to work with PyPy.
  * Code cleanup: fix code style to satisfy flake8 linter.
  * Rename www directory to docs.
* Fri Dec 29 2017 mpluskal@suse.com
- Conflict with python-cheetah
* Thu Dec 28 2017 jengelh@inai.de
- Remove some filler wording from descriptions.
  The summary can do without repeating the software name.
- Avoid running fdupes over partition boundaries.
* Sun Dec 24 2017 mpluskal@suse.com
- Cleanup spec file
  * Run spec-cleaner
  * Remove text that does not belong to describtions
  * Install license
- Build only python3 version
* Thu Dec  7 2017 boris@steki.net
- initial packaging
